==> arna-0.4.9.tar.gz: example/lib/strings.dart <==
abstract class Strings {
  static const String appName = 'Arna Gallery';
  static const String arna = 'Arna Framework';
  static const String about = 'About';
  static const String settings = 'Settings';
  static const String hello = 'Hello World';
  static const String add = 'Add';
  static const String widgets = 'Widgets';
  static const String typography = 'Typography';
  static const String description = 'A unique set of widgets for building applications with Flutter.';
  static const String source = 'Source code';
  static const String ok = 'OK';
  static const String buttonPushed = 'You have pushed the button this many times:';
  static const String theme = 'Theme';
  static const String system = 'System';
  static const String dark = 'Dark';
  static const String light = 'Light';
  static const String scaffold = 'Scaffold';
  static const String masterMode = 'Use Master-Detail';
  static const String accent = 'Accent';
  static const String lorem = 'Lorem ipsum dolor';
  static const String bannerTitle = 'This is a banner.';
  static const String buttons = 'Buttons';
  static const String first = 'First Item';
  static const String second = 'Second Item';
  static const String third = 'Third Item';
  static const String selected = 'Selected:';
  static const String linkedButtons = 'Linked Buttons';
  static const String segmentedControl = 'Segmented Control';
  static const String checkBox = 'CheckBox';
  static const String subtitle = 'Subtitle';
  static const String radio = 'Radio';
  static const String switchText = 'Switch';
  static const String listTile = 'List Tile';
  static const String title = 'Title';
  static const String slider = 'Slider';
  static const String indicator = 'Indicator';
  static const String textField = 'Text Field';
  static const String banners = 'Banner and SnackBar';
  static const String showBanner = 'Show Banner';
  static const String showSnackBar = 'Show SnackBar';
  static const String pickers = 'Pickers';
  static const String datePicker = 'Date Picker';
}

==> arna-1.0.1.tar.gz: example/lib/strings.dart <==
abstract class Strings {
  static const String appName = 'Arna Gallery';
  static const String arna = 'Arna';
  static const String about = 'About';
  static const String settings = 'Settings';
  static const String hello = 'Hello World';
  static const String add = 'Add';
  static const String search = 'Search';
  static const String widgets = 'Widgets';
  static const String typography = 'Typography';
  static const String description = 'A set of widgets designed to be simple and easy to use for building applications.';
  static const String source = 'Source code';
  static const String licenses = 'Licenses';
  static const String ok = 'OK';
  static const String buttonPushed = 'You have pushed the button this many times:';
  static const String theme = 'Theme';
  static const String system = 'System';
  static const String dark = 'Dark';
  static const String light = 'Light';
  static const String options = 'Options';
  static const String masterMode = 'Use Master-Detail';
  static const String blurMode = 'Show blur on dialogs';
  static const String accent = 'Accent';
  static const String lorem = 'Lorem ipsum dolor';
  static const String bannerTitle = 'This is a banner.';
  static const String buttons = 'Buttons';
  static const String first = 'First Item';
  static const String second = 'Second Item';
  static const String third = 'Third Item';
  static const String selected = 'Selected:';
  static const String linkedButtons = 'Linked Buttons';
  static const String segmentedControl = 'Segmented Control';
  static const String checkBox = 'CheckBox';
  static const String subtitle = 'Subtitle';
  static const String radio = 'Radio';
  static const String switchText = 'Switch';
  static const String listTile = 'List Tile';
  static const String title = 'Title';
  static const String slider = 'Slider';
  static const String indicator = 'Indicator';
  static const String textField = 'Text Field';
  static const String banners = 'Banner and SnackBar';
  static const String showBanner = 'Show Banner';
  static const String showSnackBar = 'Show SnackBar';
  static const String pickers = 'Pickers';
  static const String datePicker = 'Date Picker';
}
